;------------------------------------------------------------------------------
;  parse.asm
;
;  - parse the serial buffer and extract the command information
;
;  Andrew Cooper
;  http://www.darkerview.com
;  CC BY-SA 4.0 - Attribution-ShareAlike 4.0 International
;
;  6Feb2017 A. Cooper
;  - initial version for GenPIC, from Incline
;
;------------------------------------------------------------------------------

;------------------------------------------------------------------------------
;  Global Definitions
	include	PIC18F66K80.inc ;processor specific definitions
	include	"defs.asm"

;------------------------------------------------------------------------------
;  Declarations	
	UDATA_ACS
parsePrm	res	2	;parse parameter result
temp	res	1	;internal calculation registers
count	res	1
char	res	1
	
;------------------------------------------------------------------------------
;  Available Resources
	global	ParseCmd, ParseDec, parsePrm
	
;------------------------------------------------------------------------------
;  External Resources
	extern	cmdCode
	extern	serFlag, serBuf, SerDump
	extern	HostMsg, HostMsgCErr, HostMsgPErr, HostPrompt
	extern	HostLine
	
;------------------------------------------------------------------------------
;  Module Code
parse	code
		
;------------------------------------------------------------------------------
;  Parse
;
;  - parse the serial buffer and extract the command information
;  - if the command is illegal an error message is returned
;
ParseCmd	clrf	cmdCode,A	;clear result
	movlw	UPPER PrsTable ;set table pointers
	movwf	TBLPTRU,A
	movlw	HIGH PrsTable
	movwf	TBLPTRH,A
	movlw	LOW PrsTable
	movwf	TBLPTRL,A
	movlw	HIGH serBuf
	movwf	FSR0H,A
	movlw	LOW serBuf
	movwf	FSR0L,A
PrsNext	movf	POSTINC0,W,A ;get buffer char	
	movwf	char,A
	btfss	char,5,A	;uppercase command if needed
	 goto	PrsNC
	btfss	char,6,A
	 goto	PrsNC
	bcf	char,5,A
PrsNC	tblrd*+		;get char from command table
	movf	TABLAT,W,A
	btfsc	STATUS,Z,A	;skip nulls padded in data
	 goto	PrsNC
	subwf	char,W,A	;check against table
	btfss	STATUS,Z,A
	 goto	PrsNot
	tblrd*	;check for end of table entry
PrsSB	movf	TABLAT,W,A
	btfss	STATUS,Z,A ;skip padded nulls
	 goto	PrsET
	tblrd*+
	goto	PrsSB
PrsET	btfss	STATUS,N,A
	 goto	PrsNext
	return		;this was the command!
	
PrsNot	tblrd*+		;skip to end of table entry
	movf	TABLAT,W,A
	btfsc	STATUS,Z,A	;skip nulls padded in data
	 goto	PrsNot
	btfss	STATUS,N,A	
	 goto	PrsNot
	tblrd*		;check for end of table
	movf	TABLAT,W,A
	sublw	0x0A	;check for end of table
	btfsc	STATUS,N,A	
	 goto	PrsCmdErr
	movlw	HIGH serBuf	;reset pointer into serBuf
	movwf	FSR0H,A
	movlw	LOW serBuf
	movwf	FSR0L,A
	incf	cmdCode,F,A	;try next command
	goto	PrsNext

PrsCmdErr	movf	serBuf,W,A	;check for empty command
	sublw	0x0D
	btfsc	STATUS,Z,A
	 goto	PrsNoCmd
	call	HostMsgCErr	;no valid command, reset for next command
PrsNoCmd	clrf	cmdCode,A
	bcf	serFlag,serCmd,A
	return

;command table
PrsTable	da	"RST",0xFF	;00
	da	"CLK",0xFF	;01
	da	"ENC",0xFF	;02
	da	"TMP",0xFF	;03
	da	"XXX",0xFF	;04
	da	"XXX",0xFF	;05
	da	"XXX",0xFF	;06
	da	"XXX",0xFF	;07
	da	"XXX",0xFF	;08
	da	"XXX",0xFF	;09
	da	"XXX",0xFF	;0A
	da	"XXX",0xFF	;0B
	da	"XXX",0xFF	;0C
	da	"XXX",0xFF	;0D
	da	"XXX",0xFF	;0E
	da	"HLP",0xFF	;0F
	da	0x0A,0x0A	;table end flag

;------------------------------------------------------------------------------
;  ParseDec
;  - get and decode the parameter
;  - the parameter is up to four digits of decimal characters
;  - put the value into two bytes of binary data
;  - if illegal data sent decode what it can else return 0
;  - limited to four digits, thus will always fit in two bytes
;  - result in parsePrm, high byte first
;
;  10 Oct 2003  A. Cooper
;  - Initial version
;
;------------------------------------------------------------------------------
ParseDec	clrf	parsePrm,A	;clear the result
	clrf	parsePrm+1,A
	movlw	0x04	;set digit counter
	movwf	count,A
	movlw	HIGH serBuf ;set pointer into buffer
	movwf	FSR0H,A
	movlw	LOW serBuf
	movwf	FSR0L,A
	movf	POSTINC0,W,A ;skip four chars
	movf	POSTINC0,W,A
	movf	POSTINC0,W,A
	movf	POSTINC0,W,A
	
ParseDecLp	movf	INDF0,W,A	;valid charater 0-9?
	addlw	0xC6	;addlw 255 - '9'
	addlw	0x0B	;addlw ('9'-'0')+1
	btfss	STATUS,C,A	;carry set if in range '0' to '9'
	 return
	movff	parsePrm,temp ;new char, multiply result regs x10
	movlw	0x0A	;do lower byte
	mulwf	parsePrm+1
	movf	PRODH,W,A
	movwf	parsePrm,A
	movf	PRODL,W,A
	movwf	parsePrm+1,A
	movlw	0x0A	;do high byte
	mulwf	temp
	movf	PRODL,W,A
	addwf	parsePrm,F,A ;neglect carry, not possible in four digits
	movlw	0x30	;subtract ASCII '0'
	subwf	POSTINC0,W,A
	addwf	parsePrm+1,F,A
	btfsc	STATUS,C
	 incf	parsePrm,F,A
	decfsz	count,F,A	;dec and check digit counter
	 goto	ParseDecLp
	return
	
	end
;-- parse.asm -----------------------------------------------------------------
