;------------------------------------------------------------------------------
;  Serial
;
;  - handle the serial ports on the PIC18F66K80
;  - declare a 16 byte buffer for each port
;  - ports fixed to 9600,8,N,1 settings, no autobaud
;
;  Andrew Cooper
;  http://www.darkerview.com
;  CC BY-SA 4.0 - Attribution-ShareAlike 4.0 International
;
;  7Mar2016 A. Cooper
;  - initial version, from Incline
;  6Feb2017 A. Cooper
;  - modified for GenPIC
;  11Feb2017 A. Cooper
;  - added second serial port
;
;------------------------------------------------------------------------------
;  Baud Rate Generator Settings
;
;  16-Bit Baud Rate Generator (BRGH & BRG16=1)								
;	Fosc=16MHz			
;	Baud	SPBRG H:L	Result	Error
;	1200	3332 =0x0D04	1200	 0.0001
;	2400	1666 =0x0682	2400	-0.0002
;	9600	416  =0x01A0	9592	-0.0008
;	12800	311  =0x0137	12821	 0.0016
;	57600	68   =0x0044	57971	 0.0064
;	115200	34   =0x0022	114286	-0.0080
;
;------------------------------------------------------------------------------

;------------------------------------------------------------------------------
;  Global Definitions
	include	PIC18F66K80.inc ;processor specific definitions
	include	"defs.asm"

;------------------------------------------------------------------------------
;  Baud Rates
ser1BaudH	equ	0x01
ser1BaudL	equ	0xA0
ser2BaudH	equ	0x01
ser2BaudL	equ	0xA0

;------------------------------------------------------------------------------
;  Declarations
	UDATA_ACS
serFlag	res	1	;flags for serial port control
serPtr	res	1	;pointer into serial buffer 1
serBuf	res	16
ser2Ptr	res	1	;pointer into serial buffer 2
ser2Buf	res	16
count	res	1

;bits within serFlag (move to defs.asm for global use)
;serOpen	equ	0	;port is active and ready
;serCmd	equ	1	;command received, <cr> found
;serBufOv	equ	2	;buffer overflow
;serBusy	equ	3	;port is busy, <CTS> not active
;ser2Open	equ	4	;port2  is active and ready
;ser2Cmd	equ	5	;command received, <cr> found
;ser2BufOv	equ	6	;buffer 2 overflow
;ser2Busy	equ	7	;port 2 is busy, <CTS> not active

;------------------------------------------------------------------------------
;  Available Resources
	global	SerInit, Ser2Init
	global	SerGetCh, Ser2GetCh
	global	SerClear, Ser2Clear
	global	SerSend, SerSendDec, Ser2Send, Ser2SendDec
	global	SerDump
	global	serFlag, serBuf, serPtr, ser2Buf, ser2Ptr

;------------------------------------------------------------------------------
;  External Resources
	extern	HostHexSp, userFlag

;------------------------------------------------------------------------------
;  Module Code
serial	code

;------------------------------------------------------------------------------
;  SerInit
;  - setup primary serial port
;  - setup bits in TXSTA1:
;	7: 0 clock source don't care in asynch
;	6: 0 eight bit data transmission
;	5: 1 transmit enabled
;	4: 0 asynchronous mode
;	3: 0 no break char
;	2: 1 BRGH low speed buad
;	1: 1 TSR empty
;	0: 0 ninth TX bit (if using 9 bit data)
;  - setup bits in RCSTA1:
;	7: 1 serial port enabled
;	6: 0 eight bit data reception
;	5: 0 single recieve (sync only)
;	4: 1 enable receiver
;	3: 0 no address mode
;	2: 0 no framing error
;	1: 0 no overrun error
;	0: 0 ninth RX bit (if using 9 bit data)
;  - setup bits in BAUDCON1:
;	7: 0 autobaud rollover
;	6: 0 RX active (read only)
;	5: 0 RX data not inverted
;	4: 0 TX idle is high
;	3: 1 16 bit baud rate generator
;	2: 0 not used
;	1: 0 no wakeup enable
;	0: 0 autobaud disabled
;
SerInit	clrf	serFlag,A	;clear flags
	clrf	serPtr,A	;clear internal variables
	movlw	B'00100110'	;set transmission control register
	movwf	TXSTA1,A
	movlw	B'10010000'	;set receive control register
	movwf	RCSTA1,A
	movlw	B'00001000'	;set baud rate control register
	movwf	BAUDCON1,A
	movlw	ser1BaudL	;set baud rate generator for baud rate
	movwf	SPBRG1
	movlw	ser1BaudH	;set baud rate generator for baud rate
	movwf	SPBRGH1
	bcf	serDir,serCTS	;set CTS and RTS pins to outputs
	bsf	serDir,serRTS
	bcf	serPort,serCTS ;set CTS and RTS low
	bsf	serPort,serRTS
	bsf	PIE1,RC1IE,A	;enable serial receive interrupt
	bsf	serFlag,serOpen,A ;show port open
	return
	
;------------------------------------------------------------------------------
;  Ser2Init
;  - setup secondary serial port
;  - setup bits in TXSTA2:
;	7: 0 clock source don't care in asynch
;	6: 0 eight bit data transmission
;	5: 1 transmit enabled
;	4: 0 asynchronous mode
;	3: 0 no break char
;	2: 1 BRGH low speed buad
;	1: 1 TSR empty
;	0: 0 ninth TX bit (if using 9 bit data)
;  - setup bits in RCSTA2:
;	7: 1 serial port enabled
;	6: 0 eight bit data reception
;	5: 0 single recieve (sync only)
;	4: 1 enable receiver
;	3: 0 no address mode
;	2: 0 no framing error
;	1: 0 no overrun error
;	0: 0 ninth RX bit (if using 9 bit data)
;  - setup bits in BAUDCON2:
;	7: 0 autobaud rollover
;	6: 0 RX active (read only)
;	5: 0 RX data not inverted
;	4: 0 TX idle is high
;	3: 1 16 bit baud rate generator
;	2: 0 not used
;	1: 0 no wakeup enable
;	0: 0 autobaud disabled
;
Ser2Init	clrf	serFlag,A	;clear flags
	clrf	serPtr,A	;clear internal variables
	movlw	B'00100110'	;set transmission control register
	movwf	TXSTA2,A
	movlw	B'10010000'	;set receive control register
	movwf	RCSTA2,A
	movlw	B'00001000'	;set baud rate control register
	movwf	BAUDCON2,A
	movlw	ser2BaudL	;set baud rate generator for baud rate
	movwf	SPBRG2
	movlw	ser2BaudH
	movwf	SPBRGH2
	bcf	ser2Dir,serCTS2 ;set CTS and RTS pins to outputs
	bsf	ser2Dir,serRTS2
	bcf	ser2Port,serCTS2 ;set CTS and RTS low
	bsf	ser2Port,serRTS2
	bsf	PIE3,RC2IE,A	;enable serial receive interrupt
	bsf	serFlag,serOpen,A ;show port open
	return

;------------------------------------------------------------------------------
;  SerGetCh
;  - handle an input charater if present
;  - usually called when a serial interrupt ocurrs
;  - char moved to input buffer
;  - processing flag raised if <cr> received
;
SerGetCh	bcf	serPort,serCTS
	btfsc	RCSTA1,OERR	;clear hardware overrun error
	 bcf	RCSTA1,CREN
	bsf	RCSTA1,CREN
	bcf	serFlag,serCmd,A
	bsf	userFlag,userLED2On,A ;set com LED
	movlw	low serBuf	;setup buffer write
	addwf	serPtr,w,A
	movwf	FSR1L,A
	clrf	FSR1H,A
	movf	RCREG1,w,A	;save recieved character
	movwf	INDF1,A
SerGetWait	btfss	PIR1,TX1IF,A ;echo the recieved character
	 goto	SerGetWait
	movwf	TXREG1,A	;send the byte
	incf	serPtr,F,A	;increment pointer
	btfsc	serPtr,4,A	;check for buffer overflow
	 bsf	serFlag,serBufOv,A
	btfsc	serPtr,4,A	;insure no buffer overflow
	 clrf	serPtr,A	;reset on overflow
	;sublw	0x0A	;check for <Newline>
	sublw	0x0D	;check for <CR>
	btfss	STATUS,Z,A
	 return
	movlw	0x0A	;send <NewLine>
SerGetWait2	btfss	PIR1,TX1IF,A
	 goto	SerGetWait2
	movwf	TXREG1	;send the byte
	clrf	serPtr,A	;reset buffer pointer
	bcf	serFlag,serBufOv,A
	bsf	serFlag,serCmd,A
	bsf	serPort,serCTS,A ;set CTS while processing command
	bsf	serFlag,serBusy,A
	return

;------------------------------------------------------------------------------
;  SerGetCh
;  - handle an input charater if present
;  - usually called when a serial interrupt ocurrs
;  - char moved to input buffer
;  - processing flag raised if <cr> received
;  - CTS use disabled (commented out) as this is a control line for the ESP-01
;
Ser2GetCh	;bcf	ser2Port,serCTS2
	btfsc	RCSTA2,OERR	;clear hardware overrun error
	 bcf	RCSTA2,CREN
	bsf	RCSTA2,CREN
	bcf	serFlag,ser2Cmd,A
	movlw	low ser2Buf	;setup buffer write
	addwf	ser2Ptr,w,A
	movwf	FSR1L,A
	clrf	FSR1H,A
	movf	RCREG2,w,A	;save recieved character
	movwf	INDF1,A
Ser2GetWait	btfss	PIR3,TX2IF,A ;echo the recieved character
	 goto	Ser2GetWait
	movwf	TXREG2,A	;send the byte
	incf	ser2Ptr,F,A	;increment pointer
	btfsc	ser2Ptr,4,A	;check for buffer overflow
	 bsf	serFlag,ser2BufOv,A
	btfsc	ser2Ptr,4,A	;insure no buffer overflow
	 clrf	ser2Ptr,A	;reset on overflow
	;sublw	0x0A	;check for <Newline>
	sublw	0x0D	;check for <CR>
	btfss	STATUS,Z,A
	 return
	movlw	0x0A	;send <NewLine>
Ser2GetWait2	btfss	PIR3,TX2IF,A
	 goto	Ser2GetWait2
	movwf	TXREG2	;send the byte
	clrf	ser2Ptr,A	;reset buffer pointer
	bcf	serFlag,ser2BufOv,A
	bsf	serFlag,ser2Cmd,A
	;bsf	ser2Port,serCTS2,A ;set CTS while processing command
	bsf	serFlag,ser2Busy,A
	return

;------------------------------------------------------------------------------
;  SerSend
;  - write a charagter out the primary serial port
;  - char to send in W on entry
;  - non-blocking, checks for finished sending on entry not exit
;  - serial send decimal adds 0x30 to convert a number to ASCII
;
SerSendDec	addlw	0x30	;convert decimal to ASCII
SerSend	btfss	PIR1,TX1IF,A	;check transmission register for empty
	 goto	SerSend
	movwf	TXREG1	;send the byte
	return

;------------------------------------------------------------------------------
;  Ser2Send
;  - write a charagter out the secondary serial port
;  - char to send in W on entry
;  - non-blocking, checks for finished sending on entry not exit
;  - serial send decimal adds 0x30 to convert a number to ASCII
;
Ser2SendDec	addlw	0x30	;convert decimal to ASCII
Ser2Send	btfss	PIR3,TX2IF,A	;check transmission register for empty
	 goto	Ser2Send
	movwf	TXREG2	;send the byte
	return
	
;------------------------------------------------------------------------------
;  SerClear
;  - clear the buffer and ready for more input
;  - set CTS for input
;  - clear buffer overflow
;
SerClear	bcf	serPort,serCTS ;set CTS
	clrf	serPtr,A	;reset buffer pointer
	bcf	serFlag,serCmd,A
	bcf	serFlag,serBufOv,A
	bcf	serFlag,serBusy,A
	bcf	userFlag,userLED2On
	return

;------------------------------------------------------------------------------
;  Ser2Clear
;  - clear buffer 2 and ready for more input
;  - set CTS 2 for input
;  - clear buffer 2 overflow
;  - CTS use disabled (commented out) as this is a control line for the ESP-01
;
Ser2Clear	;bcf	ser2Port,serCTS2 ;set CTS
	clrf	ser2Ptr,A	;reset buffer pointer
	bcf	serFlag,ser2Cmd,A
	bcf	serFlag,ser2BufOv,A
	bcf	serFlag,ser2Busy,A
	return

;------------------------------------------------------------------------------
;  SerDump
;  - dump the contents of the serial buffer in hex for testing
;
SerDump	movff	serPtr,count
	movlw	HIGH serBuf
	movwf	FSR0H,A
	movlw	LOW serBuf
	movwf	FSR0L,A
SerDumpLp	movf	POSTINC0,W,A ;get buffer char
	call	HostHexSp
	decfsz	count,F,A
	 goto	SerDumpLp
	return

	end
;-- end serial.asm ------------------------------------------------------------



