;------------------------------------------------------------------------------
;  tempConv.asm
;  - convert a thermistor temperature to decimal degrees C
;  - a standard 10k thermistor (B=3380) is biased with a 10k resistor
;  - a pre-calculated lookup table is used giving BCD values
;  - range limited to 200.0C to -50.0C
;  - upper bit of first digit is sign (high=negative) thus 0x8453 is -45.3C
;  - the table only uses 10 out of 12 bits to compress the table to 1kb, this
;  - could be improved by using the remaining 2 bits for interpolation
;
;  Andrew Cooper
;  http://www.darkerview.com
;  Copyright 2017 all rights reserved
;
;  7Feb2017 A. Cooper
;  - initial version for GenPIC
;
;------------------------------------------------------------------------------

;------------------------------------------------------------------------------
;  Global Definitions
	include	PIC18F66K80.inc ;processor specific definitions
	include	"defs.asm"

;------------------------------------------------------------------------------
;  Available Resources
	global	TempConvert
	
;------------------------------------------------------------------------------
;  External Resources
	extern	resHi, resLo

;------------------------------------------------------------------------------
;  Calibration
;  - A constant used to adjust the reading up or down to calibrate the result
;  - a signed integer to add to the A/D result for a +/-128 offset
adjust	equ	0x54
	
;------------------------------------------------------------------------------
;  Module Code
tempConv	code

;----------------------------------------------------------------------------
;  TempConvert
;
;  - convert the A/D reading to degrees C in BCD
;  - input 12bit value in resHi, reslo 
;  - output in resHi and resLo
;
TempConvert	movlw	UPPER TempTable ;set table pointer
	movwf	TBLPTRU,A
	movlw	HIGH TempTable
	movwf	TBLPTRH,A
	movlw	LOW TempTable
	movwf	TBLPTRL,A
	movlw	adjust	;add the calibration constant
	addwf	resLo,F,A
	btfsc	STATUS,C
	 incf	resHi,F,A
	movlw	0x0F	;insure the value is in range
	andwf	resHi,F,A
	bcf	STATUS,C,A	;truncate to ten bit value times two
	rrcf	resHi,F,A
	rrcf	resLo,F,A
	bcf	resLo,0,A
	movf	resLo,W,A	;add to table pointer
	addwf	TBLPTRL,F,A
	movf	resHi,W,A
	btfsc	STATUS,C
	 incfsz	resHi,W,A
	  addwf	TBLPTRH,F,A
	btfsc	STATUS,C
	 incf	TBLPTRU,F,A
	tblrd*+		;get char from conversion table
	movf	TABLAT,W,A
	movwf	resLo
	tblrd*	
	movf	TABLAT,W,A	
	movwf	resHi
	return
	
TempTable	da	0x2000	;200.0  0  0
	da	0x2000	;200.0  1  1
	da	0x2000	;200.0  2  2
	da	0x2000	;200.0  3  3
	da	0x2000	;200.0  4  4
	da	0x2000	;200.0  5  5
	da	0x2000	;200.0  6  6
	da	0x2000	;200.0  7  7
	da	0x2000	;200.0  8  8
	da	0x2000	;200.0  9  9
	da	0x2000	;200.0  A  10
	da	0x2000	;200.0  B  11
	da	0x2000	;200.0  C  12
	da	0x2000	;200.0  D  13
	da	0x1960	;196.0  E  14
	da	0x1916	;191.6  F  15
	da	0x1876	;187.6  10  16
	da	0x1839	;183.9  11  17
	da	0x1805	;180.5  12  18
	da	0x1773	;177.3  13  19
	da	0x1742	;174.2  14  20
	da	0x1714	;171.4  15  21
	da	0x1687	;168.7  16  22
	da	0x1662	;166.2  17  23
	da	0x1638	;163.8  18  24
	da	0x1616	;161.6  19  25
	da	0x1594	;159.4  1A  26
	da	0x1573	;157.3  1B  27
	da	0x1554	;155.4  1C  28
	da	0x1535	;153.5  1D  29
	da	0x1517	;151.7  1E  30
	da	0x1499	;149.9  1F  31
	da	0x1483	;148.3  20  32
	da	0x1467	;146.7  21  33
	da	0x1451	;145.1  22  34
	da	0x1436	;143.6  23  35
	da	0x1422	;142.2  24  36
	da	0x1408	;140.8  25  37
	da	0x1394	;139.4  26  38
	da	0x1381	;138.1  27  39
	da	0x1369	;136.9  28  40
	da	0x1356	;135.6  29  41
	da	0x1344	;134.4  2A  42
	da	0x1333	;133.3  2B  43
	da	0x1321	;132.1  2C  44
	da	0x1310	;131.0  2D  45
	da	0x1200	;130.0  2E  46
	da	0x1289	;128.9  2F  47
	da	0x1279	;127.9  30  48
	da	0x1269	;126.9  31  49
	da	0x1260	;126.0  32  50
	da	0x1250	;125.0  33  51
	da	0x1241	;124.1  34  52
	da	0x1232	;123.2  35  53
	da	0x1223	;122.3  36  54
	da	0x1214	;121.4  37  55
	da	0x1206	;120.6  38  56
	da	0x1198	;119.8  39  57
	da	0x1189	;118.9  3A  58
	da	0x1182	;118.2  3B  59
	da	0x1174	;117.4  3C  60
	da	0x1166	;116.6  3D  61
	da	0x1159	;115.9  3E  62
	da	0x1151	;115.1  3F  63
	da	0x1144	;114.4  40  64
	da	0x1137	;113.7  41  65
	da	0x1130	;113.0  42  66
	da	0x1123	;112.3  43  67
	da	0x1116	;111.6  44  68
	da	0x1110	;111.0  45  69
	da	0x1103	;110.3  46  70
	da	0x1097	;109.7  47  71
	da	0x1091	;109.1  48  72
	da	0x1084	;108.4  49  73
	da	0x1078	;107.8  4A  74
	da	0x1072	;107.2  4B  75
	da	0x1066	;106.6  4C  76
	da	0x1061	;106.1  4D  77
	da	0x1055	;105.5  4E  78
	da	0x1049	;104.9  4F  79
	da	0x1044	;104.4  50  80
	da	0x1038	;103.8  51  81
	da	0x1033	;103.3  52  82
	da	0x1028	;102.8  53  83
	da	0x1022	;102.2  54  84
	da	0x1017	;101.7  55  85
	da	0x1012	;101.2  56  86
	da	0x1007	;100.7  57  87
	da	0x1002	;100.2  58  88
	da	0x0997	;99.7  59  89
	da	0x0992	;99.2  5A  90
	da	0x0987	;98.7  5B  91
	da	0x0983	;98.3  5C  92
	da	0x0978	;97.8  5D  93
	da	0x0973	;97.3  5E  94
	da	0x0969	;96.9  5F  95
	da	0x0964	;96.4  60  96
	da	0x0960	;96.0  61  97
	da	0x0955	;95.5  62  98
	da	0x0951	;95.1  63  99
	da	0x0947	;94.7  64  100
	da	0x0942	;94.2  65  101
	da	0x0938	;93.8  66  102
	da	0x0934	;93.4  67  103
	da	0x0930	;93.0  68  104
	da	0x0926	;92.6  69  105
	da	0x0922	;92.2  6A  106
	da	0x0918	;91.8  6B  107
	da	0x0914	;91.4  6C  108
	da	0x0910	;91.0  6D  109
	da	0x0906	;90.6  6E  110
	da	0x0902	;90.2  6F  111
	da	0x0898	;89.8  70  112
	da	0x0895	;89.5  71  113
	da	0x0891	;89.1  72  114
	da	0x0887	;88.7  73  115
	da	0x0884	;88.4  74  116
	da	0x0880	;88.0  75  117
	da	0x0876	;87.6  76  118
	da	0x0873	;87.3  77  119
	da	0x0869	;86.9  78  120
	da	0x0866	;86.6  79  121
	da	0x0862	;86.2  7A  122
	da	0x0859	;85.9  7B  123
	da	0x0856	;85.6  7C  124
	da	0x0852	;85.2  7D  125
	da	0x0849	;84.9  7E  126
	da	0x0846	;84.6  7F  127
	da	0x0842	;84.2  80  128
	da	0x0839	;83.9  81  129
	da	0x0836	;83.6  82  130
	da	0x0833	;83.3  83  131
	da	0x0830	;83.0  84  132
	da	0x0826	;82.6  85  133
	da	0x0823	;82.3  86  134
	da	0x0820	;82.0  87  135
	da	0x0817	;81.7  88  136
	da	0x0814	;81.4  89  137
	da	0x0811	;81.1  8A  138
	da	0x0808	;80.8  8B  139
	da	0x0805	;80.5  8C  140
	da	0x0802	;80.2  8D  141
	da	0x0799	;79.9  8E  142
	da	0x0796	;79.6  8F  143
	da	0x0794	;79.4  90  144
	da	0x0791	;79.1  91  145
	da	0x0788	;78.8  92  146
	da	0x0785	;78.5  93  147
	da	0x0782	;78.2  94  148
	da	0x0779	;77.9  95  149
	da	0x0777	;77.7  96  150
	da	0x0774	;77.4  97  151
	da	0x0771	;77.1  98  152
	da	0x0769	;76.9  99  153
	da	0x0766	;76.6  9A  154
	da	0x0763	;76.3  9B  155
	da	0x0761	;76.1  9C  156
	da	0x0758	;75.8  9D  157
	da	0x0755	;75.5  9E  158
	da	0x0753	;75.3  9F  159
	da	0x0750	;75.0  A0  160
	da	0x0748	;74.8  A1  161
	da	0x0745	;74.5  A2  162
	da	0x0743	;74.3  A3  163
	da	0x0740	;74.0  A4  164
	da	0x0738	;73.8  A5  165
	da	0x0735	;73.5  A6  166
	da	0x0733	;73.3  A7  167
	da	0x0730	;73.0  A8  168
	da	0x0728	;72.8  A9  169
	da	0x0725	;72.5  AA  170
	da	0x0723	;72.3  AB  171
	da	0x0721	;72.1  AC  172
	da	0x0718	;71.8  AD  173
	da	0x0716	;71.6  AE  174
	da	0x0713	;71.3  AF  175
	da	0x0711	;71.1  B0  176
	da	0x0709	;70.9  B1  177
	da	0x0707	;70.7  B2  178
	da	0x0704	;70.4  B3  179
	da	0x0702	;70.2  B4  180
	da	0x0600	;70.0  B5  181
	da	0x0697	;69.7  B6  182
	da	0x0695	;69.5  B7  183
	da	0x0693	;69.3  B8  184
	da	0x0691	;69.1  B9  185
	da	0x0689	;68.9  BA  186
	da	0x0686	;68.6  BB  187
	da	0x0684	;68.4  BC  188
	da	0x0682	;68.2  BD  189
	da	0x0680	;68.0  BE  190
	da	0x0678	;67.8  BF  191
	da	0x0676	;67.6  C0  192
	da	0x0673	;67.3  C1  193
	da	0x0671	;67.1  C2  194
	da	0x0669	;66.9  C3  195
	da	0x0667	;66.7  C4  196
	da	0x0665	;66.5  C5  197
	da	0x0663	;66.3  C6  198
	da	0x0661	;66.1  C7  199
	da	0x0659	;65.9  C8  200
	da	0x0657	;65.7  C9  201
	da	0x0655	;65.5  CA  202
	da	0x0653	;65.3  CB  203
	da	0x0651	;65.1  CC  204
	da	0x0649	;64.9  CD  205
	da	0x0647	;64.7  CE  206
	da	0x0645	;64.5  CF  207
	da	0x0643	;64.3  D0  208
	da	0x0641	;64.1  D1  209
	da	0x0639	;63.9  D2  210
	da	0x0637	;63.7  D3  211
	da	0x0635	;63.5  D4  212
	da	0x0633	;63.3  D5  213
	da	0x0631	;63.1  D6  214
	da	0x0629	;62.9  D7  215
	da	0x0627	;62.7  D8  216
	da	0x0626	;62.6  D9  217
	da	0x0624	;62.4  DA  218
	da	0x0622	;62.2  DB  219
	da	0x0620	;62.0  DC  220
	da	0x0618	;61.8  DD  221
	da	0x0616	;61.6  DE  222
	da	0x0614	;61.4  DF  223
	da	0x0613	;61.3  E0  224
	da	0x0611	;61.1  E1  225
	da	0x0609	;60.9  E2  226
	da	0x0607	;60.7  E3  227
	da	0x0605	;60.5  E4  228
	da	0x0604	;60.4  E5  229
	da	0x0602	;60.2  E6  230
	da	0x0600	;60.0  E7  231
	da	0x0598	;59.8  E8  232
	da	0x0597	;59.7  E9  233
	da	0x0595	;59.5  EA  234
	da	0x0593	;59.3  EB  235
	da	0x0591	;59.1  EC  236
	da	0x0590	;59.0  ED  237
	da	0x0588	;58.8  EE  238
	da	0x0586	;58.6  EF  239
	da	0x0584	;58.4  F0  240
	da	0x0583	;58.3  F1  241
	da	0x0581	;58.1  F2  242
	da	0x0579	;57.9  F3  243
	da	0x0578	;57.8  F4  244
	da	0x0576	;57.6  F5  245
	da	0x0574	;57.4  F6  246
	da	0x0573	;57.3  F7  247
	da	0x0571	;57.1  F8  248
	da	0x0569	;56.9  F9  249
	da	0x0568	;56.8  FA  250
	da	0x0566	;56.6  FB  251
	da	0x0564	;56.4  FC  252
	da	0x0563	;56.3  FD  253
	da	0x0561	;56.1  FE  254
	da	0x0559	;55.9  FF  255
	da	0x0558	;55.8  100  256
	da	0x0556	;55.6  101  257
	da	0x0555	;55.5  102  258
	da	0x0553	;55.3  103  259
	da	0x0551	;55.1  104  260
	da	0x0550	;55.0  105  261
	da	0x0548	;54.8  106  262
	da	0x0547	;54.7  107  263
	da	0x0545	;54.5  108  264
	da	0x0544	;54.4  109  265
	da	0x0542	;54.2  10A  266
	da	0x0540	;54.0  10B  267
	da	0x0539	;53.9  10C  268
	da	0x0537	;53.7  10D  269
	da	0x0536	;53.6  10E  270
	da	0x0534	;53.4  10F  271
	da	0x0533	;53.3  110  272
	da	0x0531	;53.1  111  273
	da	0x0530	;53.0  112  274
	da	0x0528	;52.8  113  275
	da	0x0527	;52.7  114  276
	da	0x0525	;52.5  115  277
	da	0x0524	;52.4  116  278
	da	0x0522	;52.2  117  279
	da	0x0521	;52.1  118  280
	da	0x0519	;51.9  119  281
	da	0x0518	;51.8  11A  282
	da	0x0516	;51.6  11B  283
	da	0x0515	;51.5  11C  284
	da	0x0513	;51.3  11D  285
	da	0x0512	;51.2  11E  286
	da	0x0510	;51.0  11F  287
	da	0x0509	;50.9  120  288
	da	0x0508	;50.8  121  289
	da	0x0506	;50.6  122  290
	da	0x0505	;50.5  123  291
	da	0x0503	;50.3  124  292
	da	0x0502	;50.2  125  293
	da	0x0500	;50.0  126  294
	da	0x0499	;49.9  127  295
	da	0x0498	;49.8  128  296
	da	0x0496	;49.6  129  297
	da	0x0495	;49.5  12A  298
	da	0x0493	;49.3  12B  299
	da	0x0492	;49.2  12C  300
	da	0x0491	;49.1  12D  301
	da	0x0489	;48.9  12E  302
	da	0x0488	;48.8  12F  303
	da	0x0486	;48.6  130  304
	da	0x0485	;48.5  131  305
	da	0x0484	;48.4  132  306
	da	0x0482	;48.2  133  307
	da	0x0481	;48.1  134  308
	da	0x0479	;47.9  135  309
	da	0x0478	;47.8  136  310
	da	0x0477	;47.7  137  311
	da	0x0475	;47.5  138  312
	da	0x0474	;47.4  139  313
	da	0x0473	;47.3  13A  314
	da	0x0471	;47.1  13B  315
	da	0x0470	;47.0  13C  316
	da	0x0469	;46.9  13D  317
	da	0x0467	;46.7  13E  318
	da	0x0466	;46.6  13F  319
	da	0x0465	;46.5  140  320
	da	0x0463	;46.3  141  321
	da	0x0462	;46.2  142  322
	da	0x0461	;46.1  143  323
	da	0x0459	;45.9  144  324
	da	0x0458	;45.8  145  325
	da	0x0457	;45.7  146  326
	da	0x0455	;45.5  147  327
	da	0x0454	;45.4  148  328
	da	0x0453	;45.3  149  329
	da	0x0452	;45.2  14A  330
	da	0x0450	;45.0  14B  331
	da	0x0449	;44.9  14C  332
	da	0x0448	;44.8  14D  333
	da	0x0446	;44.6  14E  334
	da	0x0445	;44.5  14F  335
	da	0x0444	;44.4  150  336
	da	0x0443	;44.3  151  337
	da	0x0441	;44.1  152  338
	da	0x0440	;44.0  153  339
	da	0x0439	;43.9  154  340
	da	0x0438	;43.8  155  341
	da	0x0436	;43.6  156  342
	da	0x0435	;43.5  157  343
	da	0x0434	;43.4  158  344
	da	0x0432	;43.2  159  345
	da	0x0431	;43.1  15A  346
	da	0x0430	;43.0  15B  347
	da	0x0429	;42.9  15C  348
	da	0x0428	;42.8  15D  349
	da	0x0426	;42.6  15E  350
	da	0x0425	;42.5  15F  351
	da	0x0424	;42.4  160  352
	da	0x0423	;42.3  161  353
	da	0x0421	;42.1  162  354
	da	0x0420	;42.0  163  355
	da	0x0419	;41.9  164  356
	da	0x0418	;41.8  165  357
	da	0x0416	;41.6  166  358
	da	0x0415	;41.5  167  359
	da	0x0414	;41.4  168  360
	da	0x0413	;41.3  169  361
	da	0x0412	;41.2  16A  362
	da	0x0410	;41.0  16B  363
	da	0x0409	;40.9  16C  364
	da	0x0408	;40.8  16D  365
	da	0x0407	;40.7  16E  366
	da	0x0406	;40.6  16F  367
	da	0x0404	;40.4  170  368
	da	0x0403	;40.3  171  369
	da	0x0402	;40.2  172  370
	da	0x0401	;40.1  173  371
	da	0x0300	;40.0  174  372
	da	0x0398	;39.8  175  373
	da	0x0397	;39.7  176  374
	da	0x0396	;39.6  177  375
	da	0x0395	;39.5  178  376
	da	0x0394	;39.4  179  377
	da	0x0393	;39.3  17A  378
	da	0x0391	;39.1  17B  379
	da	0x0390	;39.0  17C  380
	da	0x0389	;38.9  17D  381
	da	0x0388	;38.8  17E  382
	da	0x0387	;38.7  17F  383
	da	0x0386	;38.6  180  384
	da	0x0384	;38.4  181  385
	da	0x0383	;38.3  182  386
	da	0x0382	;38.2  183  387
	da	0x0381	;38.1  184  388
	da	0x0380	;38.0  185  389
	da	0x0379	;37.9  186  390
	da	0x0378	;37.8  187  391
	da	0x0376	;37.6  188  392
	da	0x0375	;37.5  189  393
	da	0x0374	;37.4  18A  394
	da	0x0373	;37.3  18B  395
	da	0x0372	;37.2  18C  396
	da	0x0371	;37.1  18D  397
	da	0x0370	;37.0  18E  398
	da	0x0369	;36.9  18F  399
	da	0x0367	;36.7  190  400
	da	0x0366	;36.6  191  401
	da	0x0365	;36.5  192  402
	da	0x0364	;36.4  193  403
	da	0x0363	;36.3  194  404
	da	0x0362	;36.2  195  405
	da	0x0361	;36.1  196  406
	da	0x0360	;36.0  197  407
	da	0x0358	;35.8  198  408
	da	0x0357	;35.7  199  409
	da	0x0356	;35.6  19A  410
	da	0x0355	;35.5  19B  411
	da	0x0354	;35.4  19C  412
	da	0x0353	;35.3  19D  413
	da	0x0352	;35.2  19E  414
	da	0x0351	;35.1  19F  415
	da	0x0350	;35.0  1A0  416
	da	0x0349	;34.9  1A1  417
	da	0x0347	;34.7  1A2  418
	da	0x0346	;34.6  1A3  419
	da	0x0345	;34.5  1A4  420
	da	0x0344	;34.4  1A5  421
	da	0x0343	;34.3  1A6  422
	da	0x0342	;34.2  1A7  423
	da	0x0341	;34.1  1A8  424
	da	0x0340	;34.0  1A9  425
	da	0x0339	;33.9  1AA  426
	da	0x0338	;33.8  1AB  427
	da	0x0337	;33.7  1AC  428
	da	0x0335	;33.5  1AD  429
	da	0x0334	;33.4  1AE  430
	da	0x0333	;33.3  1AF  431
	da	0x0332	;33.2  1B0  432
	da	0x0331	;33.1  1B1  433
	da	0x0330	;33.0  1B2  434
	da	0x0329	;32.9  1B3  435
	da	0x0328	;32.8  1B4  436
	da	0x0327	;32.7  1B5  437
	da	0x0326	;32.6  1B6  438
	da	0x0325	;32.5  1B7  439
	da	0x0324	;32.4  1B8  440
	da	0x0323	;32.3  1B9  441
	da	0x0322	;32.2  1BA  442
	da	0x0321	;32.1  1BB  443
	da	0x0319	;31.9  1BC  444
	da	0x0318	;31.8  1BD  445
	da	0x0317	;31.7  1BE  446
	da	0x0316	;31.6  1BF  447
	da	0x0315	;31.5  1C0  448
	da	0x0314	;31.4  1C1  449
	da	0x0313	;31.3  1C2  450
	da	0x0312	;31.2  1C3  451
	da	0x0311	;31.1  1C4  452
	da	0x0310	;31.0  1C5  453
	da	0x0309	;30.9  1C6  454
	da	0x0308	;30.8  1C7  455
	da	0x0307	;30.7  1C8  456
	da	0x0306	;30.6  1C9  457
	da	0x0305	;30.5  1CA  458
	da	0x0304	;30.4  1CB  459
	da	0x0303	;30.3  1CC  460
	da	0x0302	;30.2  1CD  461
	da	0x0301	;30.1  1CE  462
	da	0x0200	;30.0  1CF  463
	da	0x0299	;29.9  1D0  464
	da	0x0298	;29.8  1D1  465
	da	0x0296	;29.6  1D2  466
	da	0x0295	;29.5  1D3  467
	da	0x0294	;29.4  1D4  468
	da	0x0293	;29.3  1D5  469
	da	0x0292	;29.2  1D6  470
	da	0x0291	;29.1  1D7  471
	da	0x0290	;29.0  1D8  472
	da	0x0289	;28.9  1D9  473
	da	0x0288	;28.8  1DA  474
	da	0x0287	;28.7  1DB  475
	da	0x0286	;28.6  1DC  476
	da	0x0285	;28.5  1DD  477
	da	0x0284	;28.4  1DE  478
	da	0x0283	;28.3  1DF  479
	da	0x0282	;28.2  1E0  480
	da	0x0281	;28.1  1E1  481
	da	0x0280	;28.0  1E2  482
	da	0x0279	;27.9  1E3  483
	da	0x0278	;27.8  1E4  484
	da	0x0277	;27.7  1E5  485
	da	0x0276	;27.6  1E6  486
	da	0x0275	;27.5  1E7  487
	da	0x0274	;27.4  1E8  488
	da	0x0273	;27.3  1E9  489
	da	0x0272	;27.2  1EA  490
	da	0x0271	;27.1  1EB  491
	da	0x0270	;27.0  1EC  492
	da	0x0269	;26.9  1ED  493
	da	0x0268	;26.8  1EE  494
	da	0x0267	;26.7  1EF  495
	da	0x0266	;26.6  1F0  496
	da	0x0265	;26.5  1F1  497
	da	0x0264	;26.4  1F2  498
	da	0x0263	;26.3  1F3  499
	da	0x0262	;26.2  1F4  500
	da	0x0261	;26.1  1F5  501
	da	0x0260	;26.0  1F6  502
	da	0x0259	;25.9  1F7  503
	da	0x0258	;25.8  1F8  504
	da	0x0257	;25.7  1F9  505
	da	0x0256	;25.6  1FA  506
	da	0x0255	;25.5  1FB  507
	da	0x0254	;25.4  1FC  508
	da	0x0253	;25.3  1FD  509
	da	0x0252	;25.2  1FE  510
	da	0x0251	;25.1  1FF  511
	da	0x0250	;25.0  200  512
	da	0x0249	;24.9  201  513
	da	0x0248	;24.8  202  514
	da	0x0247	;24.7  203  515
	da	0x0246	;24.6  204  516
	da	0x0245	;24.5  205  517
	da	0x0244	;24.4  206  518
	da	0x0243	;24.3  207  519
	da	0x0242	;24.2  208  520
	da	0x0241	;24.1  209  521
	da	0x0240	;24.0  20A  522
	da	0x0239	;23.9  20B  523
	da	0x0238	;23.8  20C  524
	da	0x0237	;23.7  20D  525
	da	0x0236	;23.6  20E  526
	da	0x0235	;23.5  20F  527
	da	0x0234	;23.4  210  528
	da	0x0233	;23.3  211  529
	da	0x0232	;23.2  212  530
	da	0x0231	;23.1  213  531
	da	0x0230	;23.0  214  532
	da	0x0229	;22.9  215  533
	da	0x0228	;22.8  216  534
	da	0x0227	;22.7  217  535
	da	0x0226	;22.6  218  536
	da	0x0225	;22.5  219  537
	da	0x0224	;22.4  21A  538
	da	0x0223	;22.3  21B  539
	da	0x0222	;22.2  21C  540
	da	0x0221	;22.1  21D  541
	da	0x0220	;22.0  21E  542
	da	0x0220	;22.0  21F  543
	da	0x0219	;21.9  220  544
	da	0x0218	;21.8  221  545
	da	0x0217	;21.7  222  546
	da	0x0216	;21.6  223  547
	da	0x0215	;21.5  224  548
	da	0x0214	;21.4  225  549
	da	0x0213	;21.3  226  550
	da	0x0212	;21.2  227  551
	da	0x0211	;21.1  228  552
	da	0x0210	;21.0  229  553
	da	0x0209	;20.9  22A  554
	da	0x0208	;20.8  22B  555
	da	0x0207	;20.7  22C  556
	da	0x0206	;20.6  22D  557
	da	0x0205	;20.5  22E  558
	da	0x0204	;20.4  22F  559
	da	0x0203	;20.3  230  560
	da	0x0202	;20.2  231  561
	da	0x0201	;20.1  232  562
	da	0x0200	;20.0  233  563
	da	0x0199	;19.9  234  564
	da	0x0198	;19.8  235  565
	da	0x0197	;19.7  236  566
	da	0x0196	;19.6  237  567
	da	0x0195	;19.5  238  568
	da	0x0194	;19.4  239  569
	da	0x0193	;19.3  23A  570
	da	0x0192	;19.2  23B  571
	da	0x0191	;19.1  23C  572
	da	0x0190	;19.0  23D  573
	da	0x0189	;18.9  23E  574
	da	0x0188	;18.8  23F  575
	da	0x0188	;18.8  240  576
	da	0x0187	;18.7  241  577
	da	0x0186	;18.6  242  578
	da	0x0185	;18.5  243  579
	da	0x0184	;18.4  244  580
	da	0x0183	;18.3  245  581
	da	0x0182	;18.2  246  582
	da	0x0181	;18.1  247  583
	da	0x0180	;18.0  248  584
	da	0x0179	;17.9  249  585
	da	0x0178	;17.8  24A  586
	da	0x0177	;17.7  24B  587
	da	0x0176	;17.6  24C  588
	da	0x0175	;17.5  24D  589
	da	0x0174	;17.4  24E  590
	da	0x0173	;17.3  24F  591
	da	0x0172	;17.2  250  592
	da	0x0171	;17.1  251  593
	da	0x0170	;17.0  252  594
	da	0x0169	;16.9  253  595
	da	0x0168	;16.8  254  596
	da	0x0167	;16.7  255  597
	da	0x0166	;16.6  256  598
	da	0x0165	;16.5  257  599
	da	0x0164	;16.4  258  600
	da	0x0163	;16.3  259  601
	da	0x0162	;16.2  25A  602
	da	0x0161	;16.1  25B  603
	da	0x0160	;16.0  25C  604
	da	0x0160	;16.0  25D  605
	da	0x0159	;15.9  25E  606
	da	0x0158	;15.8  25F  607
	da	0x0157	;15.7  260  608
	da	0x0156	;15.6  261  609
	da	0x0155	;15.5  262  610
	da	0x0154	;15.4  263  611
	da	0x0153	;15.3  264  612
	da	0x0152	;15.2  265  613
	da	0x0151	;15.1  266  614
	da	0x0150	;15.0  267  615
	da	0x0149	;14.9  268  616
	da	0x0148	;14.8  269  617
	da	0x0147	;14.7  26A  618
	da	0x0146	;14.6  26B  619
	da	0x0145	;14.5  26C  620
	da	0x0144	;14.4  26D  621
	da	0x0143	;14.3  26E  622
	da	0x0142	;14.2  26F  623
	da	0x0141	;14.1  270  624
	da	0x0140	;14.0  271  625
	da	0x0139	;13.9  272  626
	da	0x0138	;13.8  273  627
	da	0x0137	;13.7  274  628
	da	0x0136	;13.6  275  629
	da	0x0135	;13.5  276  630
	da	0x0134	;13.4  277  631
	da	0x0133	;13.3  278  632
	da	0x0132	;13.2  279  633
	da	0x0131	;13.1  27A  634
	da	0x0131	;13.1  27B  635
	da	0x0130	;13.0  27C  636
	da	0x0129	;12.9  27D  637
	da	0x0128	;12.8  27E  638
	da	0x0127	;12.7  27F  639
	da	0x0126	;12.6  280  640
	da	0x0125	;12.5  281  641
	da	0x0124	;12.4  282  642
	da	0x0123	;12.3  283  643
	da	0x0122	;12.2  284  644
	da	0x0121	;12.1  285  645
	da	0x0120	;12.0  286  646
	da	0x0119	;11.9  287  647
	da	0x0118	;11.8  288  648
	da	0x0117	;11.7  289  649
	da	0x0116	;11.6  28A  650
	da	0x0115	;11.5  28B  651
	da	0x0114	;11.4  28C  652
	da	0x0113	;11.3  28D  653
	da	0x0112	;11.2  28E  654
	da	0x0111	;11.1  28F  655
	da	0x0110	;11.0  290  656
	da	0x0109	;10.9  291  657
	da	0x0108	;10.8  292  658
	da	0x0107	;10.7  293  659
	da	0x0106	;10.6  294  660
	da	0x0105	;10.5  295  661
	da	0x0104	;10.4  296  662
	da	0x0103	;10.3  297  663
	da	0x0102	;10.2  298  664
	da	0x0101	;10.1  299  665
	da	0x0100	;10.0  29A  666
	da	0x0099	;9.9  29B  667
	da	0x0098	;9.8  29C  668
	da	0x0097	;9.7  29D  669
	da	0x0096	;9.6  29E  670
	da	0x0095	;9.5  29F  671
	da	0x0094	;9.4  2A0  672
	da	0x0093	;9.3  2A1  673
	da	0x0092	;9.2  2A2  674
	da	0x0091	;9.1  2A3  675
	da	0x0090	;9.0  2A4  676
	da	0x0089	;8.9  2A5  677
	da	0x0088	;8.8  2A6  678
	da	0x0087	;8.7  2A7  679
	da	0x0086	;8.6  2A8  680
	da	0x0085	;8.5  2A9  681
	da	0x0084	;8.4  2AA  682
	da	0x0083	;8.3  2AB  683
	da	0x0082	;8.2  2AC  684
	da	0x0081	;8.1  2AD  685
	da	0x0080	;8.0  2AE  686
	da	0x0079	;7.9  2AF  687
	da	0x0078	;7.8  2B0  688
	da	0x0077	;7.7  2B1  689
	da	0x0076	;7.6  2B2  690
	da	0x0075	;7.5  2B3  691
	da	0x0074	;7.4  2B4  692
	da	0x0073	;7.3  2B5  693
	da	0x0072	;7.2  2B6  694
	da	0x0071	;7.1  2B7  695
	da	0x0070	;7.0  2B8  696
	da	0x0069	;6.9  2B9  697
	da	0x0068	;6.8  2BA  698
	da	0x0067	;6.7  2BB  699
	da	0x0066	;6.6  2BC  700
	da	0x0065	;6.5  2BD  701
	da	0x0064	;6.4  2BE  702
	da	0x0063	;6.3  2BF  703
	da	0x0062	;6.2  2C0  704
	da	0x0061	;6.1  2C1  705
	da	0x0060	;6.0  2C2  706
	da	0x0059	;5.9  2C3  707
	da	0x0058	;5.8  2C4  708
	da	0x0057	;5.7  2C5  709
	da	0x0056	;5.6  2C6  710
	da	0x0055	;5.5  2C7  711
	da	0x0054	;5.4  2C8  712
	da	0x0053	;5.3  2C9  713
	da	0x0052	;5.2  2CA  714
	da	0x0051	;5.1  2CB  715
	da	0x0050	;5.0  2CC  716
	da	0x0049	;4.9  2CD  717
	da	0x0048	;4.8  2CE  718
	da	0x0047	;4.7  2CF  719
	da	0x0046	;4.6  2D0  720
	da	0x0045	;4.5  2D1  721
	da	0x0044	;4.4  2D2  722
	da	0x0043	;4.3  2D3  723
	da	0x0042	;4.2  2D4  724
	da	0x0041	;4.1  2D5  725
	da	0x0040	;4.0  2D6  726
	da	0x0039	;3.9  2D7  727
	da	0x0038	;3.8  2D8  728
	da	0x0037	;3.7  2D9  729
	da	0x0036	;3.6  2DA  730
	da	0x0035	;3.5  2DB  731
	da	0x0034	;3.4  2DC  732
	da	0x0032	;3.2  2DD  733
	da	0x0031	;3.1  2DE  734
	da	0x0030	;3.0  2DF  735
	da	0x0029	;2.9  2E0  736
	da	0x0028	;2.8  2E1  737
	da	0x0027	;2.7  2E2  738
	da	0x0026	;2.6  2E3  739
	da	0x0025	;2.5  2E4  740
	da	0x0024	;2.4  2E5  741
	da	0x0023	;2.3  2E6  742
	da	0x0022	;2.2  2E7  743
	da	0x0021	;2.1  2E8  744
	da	0x0020	;2.0  2E9  745
	da	0x0019	;1.9  2EA  746
	da	0x0018	;1.8  2EB  747
	da	0x0017	;1.7  2EC  748
	da	0x0016	;1.6  2ED  749
	da	0x0014	;1.4  2EE  750
	da	0x0013	;1.3  2EF  751
	da	0x0012	;1.2  2F0  752
	da	0x0011	;1.1  2F1  753
	da	0x0010	;1.0  2F2  754
	da	0x0009	;0.9  2F3  755
	da	0x0008	;0.8  2F4  756
	da	0x0007	;0.7  2F5  757
	da	0x0006	;0.6  2F6  758
	da	0x0005	;0.5  2F7  759
	da	0x0004	;0.4  2F8  760
	da	0x0003	;0.3  2F9  761
	da	0x0001	;0.1  2FA  762
	da	0x0000	;0.0  2FB  763
	da	0x8001	;-0.1  2FC  764
	da	0x8002	;-0.2  2FD  765
	da	0x8003	;-0.3  2FE  766
	da	0x8004	;-0.4  2FF  767
	da	0x8005	;-0.5  300  768
	da	0x8006	;-0.6  301  769
	da	0x8007	;-0.7  302  770
	da	0x8008	;-0.8  303  771
	da	0x8010	;-1.0  304  772
	da	0x8011	;-1.1  305  773
	da	0x8012	;-1.2  306  774
	da	0x8013	;-1.3  307  775
	da	0x8014	;-1.4  308  776
	da	0x8015	;-1.5  309  777
	da	0x8016	;-1.6  30A  778
	da	0x8017	;-1.7  30B  779
	da	0x8019	;-1.9  30C  780
	da	0x8020	;-2.0  30D  781
	da	0x8021	;-2.1  30E  782
	da	0x8022	;-2.2  30F  783
	da	0x8023	;-2.3  310  784
	da	0x8024	;-2.4  311  785
	da	0x8025	;-2.5  312  786
	da	0x8027	;-2.7  313  787
	da	0x8028	;-2.8  314  788
	da	0x8029	;-2.9  315  789
	da	0x8030	;-3.0  316  790
	da	0x8031	;-3.1  317  791
	da	0x8032	;-3.2  318  792
	da	0x8033	;-3.3  319  793
	da	0x8035	;-3.5  31A  794
	da	0x8036	;-3.6  31B  795
	da	0x8037	;-3.7  31C  796
	da	0x8038	;-3.8  31D  797
	da	0x8039	;-3.9  31E  798
	da	0x8041	;-4.1  31F  799
	da	0x8042	;-4.2  320  800
	da	0x8043	;-4.3  321  801
	da	0x8044	;-4.4  322  802
	da	0x8045	;-4.5  323  803
	da	0x8046	;-4.6  324  804
	da	0x8048	;-4.8  325  805
	da	0x8049	;-4.9  326  806
	da	0x8050	;-5.0  327  807
	da	0x8051	;-5.1  328  808
	da	0x8052	;-5.2  329  809
	da	0x8054	;-5.4  32A  810
	da	0x8055	;-5.5  32B  811
	da	0x8056	;-5.6  32C  812
	da	0x8057	;-5.7  32D  813
	da	0x8059	;-5.9  32E  814
	da	0x8060	;-6.0  32F  815
	da	0x8061	;-6.1  330  816
	da	0x8062	;-6.2  331  817
	da	0x8063	;-6.3  332  818
	da	0x8065	;-6.5  333  819
	da	0x8066	;-6.6  334  820
	da	0x8067	;-6.7  335  821
	da	0x8068	;-6.8  336  822
	da	0x8070	;-7.0  337  823
	da	0x8071	;-7.1  338  824
	da	0x8072	;-7.2  339  825
	da	0x8073	;-7.3  33A  826
	da	0x8075	;-7.5  33B  827
	da	0x8076	;-7.6  33C  828
	da	0x8077	;-7.7  33D  829
	da	0x8079	;-7.9  33E  830
	da	0x8080	;-8.0  33F  831
	da	0x8081	;-8.1  340  832
	da	0x8082	;-8.2  341  833
	da	0x8084	;-8.4  342  834
	da	0x8085	;-8.5  343  835
	da	0x8086	;-8.6  344  836
	da	0x8088	;-8.8  345  837
	da	0x8089	;-8.9  346  838
	da	0x8090	;-9.0  347  839
	da	0x8091	;-9.1  348  840
	da	0x8093	;-9.3  349  841
	da	0x8094	;-9.4  34A  842
	da	0x8095	;-9.5  34B  843
	da	0x8097	;-9.7  34C  844
	da	0x8098	;-9.8  34D  845
	da	0x8099	;-9.9  34E  846
	da	0x8101	;-10.1  34F  847
	da	0x8102	;-10.2  350  848
	da	0x8104	;-10.4  351  849
	da	0x8105	;-10.5  352  850
	da	0x8106	;-10.6  353  851
	da	0x8108	;-10.8  354  852
	da	0x8109	;-10.9  355  853
	da	0x8110	;-11.0  356  854
	da	0x8112	;-11.2  357  855
	da	0x8113	;-11.3  358  856
	da	0x8115	;-11.5  359  857
	da	0x8116	;-11.6  35A  858
	da	0x8117	;-11.7  35B  859
	da	0x8119	;-11.9  35C  860
	da	0x8120	;-12.0  35D  861
	da	0x8122	;-12.2  35E  862
	da	0x8123	;-12.3  35F  863
	da	0x8125	;-12.5  360  864
	da	0x8126	;-12.6  361  865
	da	0x8127	;-12.7  362  866
	da	0x8129	;-12.9  363  867
	da	0x8130	;-13.0  364  868
	da	0x8132	;-13.2  365  869
	da	0x8133	;-13.3  366  870
	da	0x8135	;-13.5  367  871
	da	0x8136	;-13.6  368  872
	da	0x8138	;-13.8  369  873
	da	0x8139	;-13.9  36A  874
	da	0x8141	;-14.1  36B  875
	da	0x8142	;-14.2  36C  876
	da	0x8144	;-14.4  36D  877
	da	0x8145	;-14.5  36E  878
	da	0x8147	;-14.7  36F  879
	da	0x8148	;-14.8  370  880
	da	0x8150	;-15.0  371  881
	da	0x8151	;-15.1  372  882
	da	0x8153	;-15.3  373  883
	da	0x8155	;-15.5  374  884
	da	0x8156	;-15.6  375  885
	da	0x8158	;-15.8  376  886
	da	0x8159	;-15.9  377  887
	da	0x8161	;-16.1  378  888
	da	0x8162	;-16.2  379  889
	da	0x8164	;-16.4  37A  890
	da	0x8166	;-16.6  37B  891
	da	0x8167	;-16.7  37C  892
	da	0x8169	;-16.9  37D  893
	da	0x8171	;-17.1  37E  894
	da	0x8172	;-17.2  37F  895
	da	0x8174	;-17.4  380  896
	da	0x8176	;-17.6  381  897
	da	0x8177	;-17.7  382  898
	da	0x8179	;-17.9  383  899
	da	0x8181	;-18.1  384  900
	da	0x8182	;-18.2  385  901
	da	0x8184	;-18.4  386  902
	da	0x8186	;-18.6  387  903
	da	0x8188	;-18.8  388  904
	da	0x8189	;-18.9  389  905
	da	0x8191	;-19.1  38A  906
	da	0x8193	;-19.3  38B  907
	da	0x8195	;-19.5  38C  908
	da	0x8196	;-19.6  38D  909
	da	0x8198	;-19.8  38E  910
	da	0x8200	;-20.0  38F  911
	da	0x8202	;-20.2  390  912
	da	0x8204	;-20.4  391  913
	da	0x8206	;-20.6  392  914
	da	0x8207	;-20.7  393  915
	da	0x8209	;-20.9  394  916
	da	0x8211	;-21.1  395  917
	da	0x8213	;-21.3  396  918
	da	0x8215	;-21.5  397  919
	da	0x8217	;-21.7  398  920
	da	0x8219	;-21.9  399  921
	da	0x8221	;-22.1  39A  922
	da	0x8223	;-22.3  39B  923
	da	0x8225	;-22.5  39C  924
	da	0x8227	;-22.7  39D  925
	da	0x8229	;-22.9  39E  926
	da	0x8231	;-23.1  39F  927
	da	0x8233	;-23.3  3A0  928
	da	0x8235	;-23.5  3A1  929
	da	0x8237	;-23.7  3A2  930
	da	0x8239	;-23.9  3A3  931
	da	0x8241	;-24.1  3A4  932
	da	0x8243	;-24.3  3A5  933
	da	0x8245	;-24.5  3A6  934
	da	0x8248	;-24.8  3A7  935
	da	0x8250	;-25.0  3A8  936
	da	0x8252	;-25.2  3A9  937
	da	0x8254	;-25.4  3AA  938
	da	0x8256	;-25.6  3AB  939
	da	0x8259	;-25.9  3AC  940
	da	0x8261	;-26.1  3AD  941
	da	0x8263	;-26.3  3AE  942
	da	0x8266	;-26.6  3AF  943
	da	0x8268	;-26.8  3B0  944
	da	0x8270	;-27.0  3B1  945
	da	0x8273	;-27.3  3B2  946
	da	0x8275	;-27.5  3B3  947
	da	0x8278	;-27.8  3B4  948
	da	0x8280	;-28.0  3B5  949
	da	0x8282	;-28.2  3B6  950
	da	0x8285	;-28.5  3B7  951
	da	0x8288	;-28.8  3B8  952
	da	0x8290	;-29.0  3B9  953
	da	0x8293	;-29.3  3BA  954
	da	0x8295	;-29.5  3BB  955
	da	0x8298	;-29.8  3BC  956
	da	0x8301	;-30.1  3BD  957
	da	0x8303	;-30.3  3BE  958
	da	0x8306	;-30.6  3BF  959
	da	0x8309	;-30.9  3C0  960
	da	0x8312	;-31.2  3C1  961
	da	0x8315	;-31.5  3C2  962
	da	0x8317	;-31.7  3C3  963
	da	0x8320	;-32.0  3C4  964
	da	0x8323	;-32.3  3C5  965
	da	0x8326	;-32.6  3C6  966
	da	0x8329	;-32.9  3C7  967
	da	0x8332	;-33.2  3C8  968
	da	0x8336	;-33.6  3C9  969
	da	0x8339	;-33.9  3CA  970
	da	0x8342	;-34.2  3CB  971
	da	0x8345	;-34.5  3CC  972
	da	0x8349	;-34.9  3CD  973
	da	0x8352	;-35.2  3CE  974
	da	0x8355	;-35.5  3CF  975
	da	0x8359	;-35.9  3D0  976
	da	0x8362	;-36.2  3D1  977
	da	0x8366	;-36.6  3D2  978
	da	0x8370	;-37.0  3D3  979
	da	0x8373	;-37.3  3D4  980
	da	0x8377	;-37.7  3D5  981
	da	0x8381	;-38.1  3D6  982
	da	0x8385	;-38.5  3D7  983
	da	0x8389	;-38.9  3D8  984
	da	0x8393	;-39.3  3D9  985
	da	0x8397	;-39.7  3DA  986
	da	0x8402	;-40.2  3DB  987
	da	0x8406	;-40.6  3DC  988
	da	0x8411	;-41.1  3DD  989
	da	0x8415	;-41.5  3DE  990
	da	0x8420	;-42.0  3DF  991
	da	0x8425	;-42.5  3E0  992
	da	0x8430	;-43.0  3E1  993
	da	0x8435	;-43.5  3E2  994
	da	0x8440	;-44.0  3E3  995
	da	0x8446	;-44.6  3E4  996
	da	0x8451	;-45.1  3E5  997
	da	0x8457	;-45.7  3E6  998
	da	0x8463	;-46.3  3E7  999
	da	0x8469	;-46.9  3E8  1000
	da	0x8475	;-47.5  3E9  1001
	da	0x8482	;-48.2  3EA  1002
	da	0x8489	;-48.9  3EB  1003
	da	0x8496	;-49.6  3EC  1004
	da	0x8500	;-50.0  3ED  1005
	da	0x8500	;-50.0  3EE  1006
	da	0x8500	;-50.0  3EF  1007
	da	0x8500	;-50.0  3F0  1008
	da	0x8500	;-50.0  3F1  1009
	da	0x8500	;-50.0  3F2  1010
	da	0x8500	;-50.0  3F3  1011
	da	0x8500	;-50.0  3F4  1012
	da	0x8500	;-50.0  3F5  1013
	da	0x8500	;-50.0  3F6  1014
	da	0x8500	;-50.0  3F7  1015
	da	0x8500	;-50.0  3F8  1016
	da	0x8500	;-50.0  3F9  1017
	da	0x8500	;-50.0  3FA  1018
	da	0x8500	;-50.0  3FB  1019
	da	0x8500	;-50.0  3FC  1020
	da	0x8500	;-50.0  3FD  1021
	da	0x8500	;-50.0  3FE  1022
	da	0x8500	;-50.0  3FF  1023

	end
;- end tempConv.asm -----------------------------------------------------------
